@@ -3,8 +3,7 @@ import sys
 import os
 import shutil
 
-
-from utils.general import u_rotate, mases, angle, mases_to_symbols, charges
+from simassis.general import u_rotate, mases, angle, mases_to_symbols, charges
 
 
 def path_restart(fpath):
@@ -128,7 +127,6 @@ def lammps_to(filein, args):
     lines = file.readlines()
     file.close()
     
-    
     if 'Masses' in lines[9]:
         shift = 0
     elif 'Masses' in lines[10]:
@@ -136,7 +134,7 @@ def lammps_to(filein, args):
     else:
         print('something wrong with position of first few lines')
         shift = 1000000
-#    print(shift)
+
     name = lines[0]
     atoms_quantity_total = int(lines[2].split()[0])
     atoms_variety = int(lines[3].split()[0])
@@ -178,6 +176,49 @@ def lammps_to(filein, args):
         atoms_quantity.append(np.sum(pos_type==a))
     return configuration(name, basex, basey, basez, 'Cartesian', atoms_type, atoms_quantity, atoms_variety, positions_splited)
 
+def lammps_dump_to(filein, args):
+    file = open(filein)
+    lines = file.readlines()
+    file.close()
+
+    frame = args[0]
+    steps = len([l for l in lines if 'ITEM: TIMESTEP' in l])
+    step_len = len(lines)/steps
+    if frame<0:
+        frame = steps+frame
+    frame_beg = int(frame*step_len + 9)
+    frame_end = int((frame+1)*step_len)
+        
+    name = 'noname'
+    atoms_quantity_total = int(lines[3].split()[0])
+
+    basis = lines[5:8]
+    basis = [b.split() for b in basis]
+
+    xl = np.asanyarray(basis[0][:2],float)
+    yl = np.asanyarray(basis[1][:2],float)
+    zl = np.asanyarray(basis[2][:2],float)
+
+    basex = np.array([xl[1]-xl[0], 0, 0])
+    basey = np.array([0, yl[1]-yl[0], 0])
+    basez = np.array([0, 0, zl[1]-zl[0]])
+
+    data = lines[frame_beg:frame_end]
+    data = np.array([d.split() for d in data], dtype=float)
+    atom_types = np.array(data[:,0]-1, dtype=int)
+    atom_masses = data[:,1]
+    atom_masses_unique = np.unique(atom_masses)
+    atoms_variety = len(atom_masses_unique)
+    atoms_type = [mases_to_symbols[a] for a in atom_masses_unique]
+
+    positions = data[:,2:]
+    positions_splited = []
+    atoms_quantity = []
+    for a in range(atoms_variety):
+        positions_splited.append(positions[atom_types==a,:])
+        atoms_quantity.append(np.sum(atom_types==a))
+    return configuration(name, basex, basey, basez, 'Cartesian', atoms_type, atoms_quantity, atoms_variety, positions_splited)
+
 def to_poscar(
         name,
         basex, basey, basez,
@@ -185,8 +226,10 @@ def to_poscar(
         atoms_type, atoms_quantity, atoms_variety,
         positions_splited,
         fileout,
+        args,
         ):    
     poscar = [name]
+    poscar.append('\n')
     poscar.append('1.0\n')
     poscar.append('\t'+str(basex[0])+'\t'+str(basex[1]) +'\t' + str(basex[2]) + '\n')
     poscar.append('\t'+str(basey[0])+'\t'+str(basey[1]) +'\t' + str(basey[2]) + '\n')
@@ -313,7 +356,6 @@ def to_lammps(
                         )
                 n += 1
 
-        
     text = "".join(text)
     file = open(fileout, 'w')
     file.write(text)
@@ -359,12 +401,24 @@ class configuration:
                         fileout,
                         args,
                     )
+        if file_format=='lammps-dump':
+            to_lammps_dump(
+                        self.name,
+                        self.basex, self.basey, self.basez,
+                        self.cart_dir,
+                        self.atoms_type, self.atoms_quantity, self.atoms_variety,
+                        self.positions_splited,
+                        fileout,
+                        args,
+                    )
 
 def read_configuration(fname, file_format, args=[]):
     if file_format=='vasp':
         return poscar_to(fname, args)
     elif file_format=='lammps':
         return lammps_to(fname, args)
+    elif file_format=='lammps-dump':
+        return lammps_dump_to(fname, args)
     else:
         print('wrong file format')
         return 0
